==> zio-aws-ssm_2.13-5.17.158.3-sources.jar: zio/aws/ssm/model/ResetServiceSettingResponse.scala <==
package zio.aws.ssm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ResetServiceSettingResponse(
    serviceSetting: Option[zio.aws.ssm.model.ServiceSetting] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse = {
    import ResetServiceSettingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
      .builder()
      .optionallyWith(serviceSetting.map(value => value.buildAwsValue()))(
        _.serviceSetting
      )
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.ResetServiceSettingResponse.ReadOnly =
    zio.aws.ssm.model.ResetServiceSettingResponse.wrap(buildAwsValue())
}
object ResetServiceSettingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.ResetServiceSettingResponse =
      zio.aws.ssm.model.ResetServiceSettingResponse(
        serviceSetting.map(value => value.asEditable)
      )
    def serviceSetting: Option[zio.aws.ssm.model.ServiceSetting.ReadOnly]
    def getServiceSetting
        : ZIO[Any, AwsError, zio.aws.ssm.model.ServiceSetting.ReadOnly] =
      AwsError.unwrapOptionField("serviceSetting", serviceSetting)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
  ) extends zio.aws.ssm.model.ResetServiceSettingResponse.ReadOnly {
    override val serviceSetting
        : Option[zio.aws.ssm.model.ServiceSetting.ReadOnly] = scala
      .Option(impl.serviceSetting())
      .map(value => zio.aws.ssm.model.ServiceSetting.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
  ): zio.aws.ssm.model.ResetServiceSettingResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssm_2.13-5.17.267.6-sources.jar: zio/aws/ssm/model/ResetServiceSettingResponse.scala <==
package zio.aws.ssm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ResetServiceSettingResponse(
    serviceSetting: Optional[zio.aws.ssm.model.ServiceSetting] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse = {
    import ResetServiceSettingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
      .builder()
      .optionallyWith(serviceSetting.map(value => value.buildAwsValue()))(
        _.serviceSetting
      )
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.ResetServiceSettingResponse.ReadOnly =
    zio.aws.ssm.model.ResetServiceSettingResponse.wrap(buildAwsValue())
}
object ResetServiceSettingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.ResetServiceSettingResponse =
      zio.aws.ssm.model.ResetServiceSettingResponse(
        serviceSetting.map(value => value.asEditable)
      )
    def serviceSetting: Optional[zio.aws.ssm.model.ServiceSetting.ReadOnly]
    def getServiceSetting
        : ZIO[Any, AwsError, zio.aws.ssm.model.ServiceSetting.ReadOnly] =
      AwsError.unwrapOptionField("serviceSetting", serviceSetting)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
  ) extends zio.aws.ssm.model.ResetServiceSettingResponse.ReadOnly {
    override val serviceSetting
        : Optional[zio.aws.ssm.model.ServiceSetting.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.serviceSetting())
        .map(value => zio.aws.ssm.model.ServiceSetting.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.ResetServiceSettingResponse
  ): zio.aws.ssm.model.ResetServiceSettingResponse.ReadOnly = new Wrapper(impl)
}
